import re
from pathlib import Path

def compute_fc_days_from_cnt4(file, fclen_s : float):
    #Compute the FCdays from the time of the CNT4 of IFS
    #Expected to get the fclen in seconds!
    with open(file) as file:
        for l in file.readlines():
            if re.search("1 CNT4", l):
                cnt4_s = float(l.split()[7]) / 1000
                return fclen_s / cnt4_s
    return None
        
def get_fc_days_from_node_file(file):
    #Get the FCdays from the tail of the NODE file:
    with open(file) as file:
        for l in file.readlines():
            if re.search("FORECAST DAYS PER DAY", l):
                return float(l.split()[4])
    return None

def get_fc_days_from_ifs_stat(file):
    pass

def parse_path(path):
    # Returns the number of nodes, forecast lenght (in days) and slurm job id
    # For the default path structure generated via RAPS
    d = path.split(".")
    nodes = int(d[1].replace("N", ""))
    fclen = int(d[0].replace("h", "")) / 24
    slurm_id = int(d[-1].split("-")[-1])

    return nodes, fclen, slurm_id

def parse_output_dir(files, resolutions=["tco79", "tco1279", "tco2559", "tco399"]):
    # For use case 2, finds all the NODE files below the 
    # files directory
    data = {}   # resolution -> {#Nodes -> fclen slurm_id SDPD}

    for res in resolutions:
        if res not in data:
            data[res] = {}
            print(f"Checking folder {files} for {res}...")

            for file in Path(files + f'/{res}l137').rglob('NODE.001_01'):
                nodes, fclen, slurm_id = parse_path(str(file.parts[-2]))
                fc = compute_fc_days_from_cnt4(str(file), fclen_s=fclen*24*3600)
                #fc=get_fc_days_from_node_file(str(file))
                
                if fc is not None: #not location and fc is not None
                    data[res][f"{nodes} {slurm_id}"] = f"{fclen} {round(fc, 2)}"
                else:
                    data[res][f"{nodes} {slurm_id}"] = f"{fclen} NaN"

    print("resolution - nodes-slurm-id - fclen (days) - SDPD")
    for resolution, results in data.items():
        # sort by node count:
        results = dict(sorted(results.items(), key=lambda item : int(item[0].split()[0])))
        for setup, sdpd in results.items():
            print(f"{resolution : ^10} {setup : ^20} {sdpd} ")